==> openGion6.9.8.0_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE39S.sql <==
/****************************************************************************/
/* GE39 ( ﾌｧｲﾙ管理ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2018/03/29 14:26:08                                            */
/****************************************************************************/

CREATE TABLE GE39 (
   UNIQ_ID      VARCHAR2 (   10 )                   NOT NULL            /*  10 UNIQ番号     */
 , SEQNO        NUMBER   (    7 )       DEFAULT 0   NOT NULL            /*  20 表示順       */
 , SYSTEM_ID    VARCHAR2 (   10 )                   NOT NULL            /*  30 ｼｽﾃﾑID       */
 , SYFILE       VARCHAR2 (  100 )                   NOT NULL            /*  40 ﾌｧｲﾙ種別     */
 , REF_KEY      VARCHAR2 (  100 )                   NOT NULL            /*  50 関連ｷｰ       */
 , SUFFIX       VARCHAR2 (   10 )                                       /*  60 拡張子       */
 , SYNAME       VARCHAR2 (  200 )                                       /*  70 種別名称     */
 , SAVE_FOLDER  VARCHAR2 (  300 )                                       /*  80 保管ﾌｫﾙﾀﾞ    */
 , FILE_URL     VARCHAR2 (  300 )                                       /*  90 ﾌｧｲﾙURL      */
 , ICON_URL     VARCHAR2 (  300 )                                       /* 100 ｱｲｺﾝURL      */
 , ROLES        VARCHAR2 (  500 )                                       /* 110 ﾛｰﾙｽﾞ        */
 , SU_LMT       NUMBER   (    5 )       DEFAULT 0   NOT NULL            /* 120 閲覧制限数   */
 , DY_LMT       NUMBER   (    5 )       DEFAULT 0   NOT NULL            /* 130 閲覧期日     */
 , FGANGO       VARCHAR2 (    1 )       DEFAULT '0' NOT NULL            /* 140 暗号化FG     */
 , FGZIP        VARCHAR2 (    1 )       DEFAULT '0' NOT NULL            /* 150 圧縮FG       */
 , FILE_NAME    VARCHAR2 (  500 )                                       /* 160 ﾌｧｲﾙ名称     */
 , CONTENTS     VARCHAR2 ( 4000 )                                       /* 170 内容         */
 , FG_NEW       VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 180 最新FG       */
 , SIZE_FILE    NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 190 ﾌｧｲﾙｻｲｽﾞ     */
 , DYFILESET    VARCHAR2 (   14 )                                       /* 200 ﾌｧｲﾙ登録日時 */
 , USRTOROKU    VARCHAR2 (   10 )                                       /* 210 ﾌｧｲﾙ登録者   */
 , SETGUIID     VARCHAR2 (   10 )                                       /* 220 登録画面ID   */
 , FGKOSHIN     VARCHAR2 (    1 )       DEFAULT '1'                     /* 230 変更許可FG   */
 , FGKOKAI      VARCHAR2 (    1 )       DEFAULT '1'                     /* 240 公開許可FG   */
 , SRCHKEY1     VARCHAR2 (  500 )                                       /* 250 検索ｷｰ1      */
 , SRCHKEY2     VARCHAR2 (  500 )                                       /* 270 検索ｷｰ2      */
 , SRCHKEY3     VARCHAR2 (  500 )                                       /* 280 検索ｷｰ3      */
 , SRCHKEY4     VARCHAR2 (  500 )                                       /* 290 検索ｷｰ4      */
 , SRCHKEY5     VARCHAR2 (  500 )                                       /* 300 検索ｷｰ5      */
 , SRCHKEY6     VARCHAR2 (  500 )                                       /* 310 検索ｷｰ6      */
 , SRCHKEY7     VARCHAR2 (  500 )                                       /* 320 検索ｷｰ7      */
 , SRCHKEY8     VARCHAR2 (  500 )                                       /* 330 検索ｷｰ8      */
 , SRCHKEY9     VARCHAR2 (  500 )                                       /* 340 検索ｷｰ9      */
 , SRCHKEY10    VARCHAR2 (  500 )                                       /* 350 検索ｷｰ10     */
 , UNIQ         NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (   14 )                                       /* 820 登録日時     */
 , PGSET        VARCHAR2 (   10 )                                       /* 830 作成PG       */
 , PGPSET       VARCHAR2 (   10 )                                       /* 840 作成親PG     */
 , USRSET       VARCHAR2 (   10 )                                       /* 850 作成社員     */
 , DYUPD        VARCHAR2 (   14 )                                       /* 860 更新日時     */
 , PGUPD        VARCHAR2 (   10 )                                       /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (   10 )                                       /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (   10 )                                       /* 890 更新者       */
)
TABLESPACE GETBL01;


CREATE SEQUENCE GE39S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;


CREATE OR REPLACE TRIGGER GE39T00 
  BEFORE INSERT ON GE39
  FOR EACH ROW 
  BEGIN 
    SELECT GE39S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion7.2.2.0_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE39S.sql <==
/****************************************************************************/
/* GE39 ( ﾌｧｲﾙ管理ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2018/09/28 16:03:20                                            */
/****************************************************************************/

CREATE TABLE GE39 (
   UNIQ_ID      VARCHAR2 (   10 )                   NOT NULL            /*  10 UNIQ番号     */
 , SEQNO        NUMBER   (    7 )       DEFAULT 0   NOT NULL            /*  20 表示順       */
 , SYSTEM_ID    VARCHAR2 (   10 )                   NOT NULL            /*  30 ｼｽﾃﾑID       */
 , SYFILE       VARCHAR2 (  100 )                   NOT NULL            /*  40 ﾌｧｲﾙ種別     */
 , REF_KEY      VARCHAR2 (  100 )                   NOT NULL            /*  50 関連ｷｰ       */
 , SUFFIX       VARCHAR2 (   10 )                                       /*  60 拡張子       */
 , SYNAME       VARCHAR2 (  200 )                                       /*  70 種別名称     */
 , SAVE_FOLDER  VARCHAR2 (  300 )                                       /*  80 保管ﾌｫﾙﾀﾞ    */
 , FILE_URL     VARCHAR2 (  300 )                                       /*  90 ﾌｧｲﾙURL      */
 , ICON_URL     VARCHAR2 (  300 )                                       /* 100 ｱｲｺﾝURL      */
 , ROLES        VARCHAR2 ( 2000 )                                       /* 110 ﾛｰﾙｽﾞ        */
 , SU_LMT       NUMBER   (    5 )       DEFAULT 0   NOT NULL            /* 120 閲覧制限数   */
 , DY_LMT       NUMBER   (    5 )       DEFAULT 0   NOT NULL            /* 130 閲覧期日     */
 , FGANGO       VARCHAR2 (    1 )       DEFAULT '0' NOT NULL            /* 140 暗号化FG     */
 , FGZIP        VARCHAR2 (    1 )       DEFAULT '0' NOT NULL            /* 150 圧縮FG       */
 , FILE_NAME    VARCHAR2 (  500 )                                       /* 160 ﾌｧｲﾙ名称     */
 , CONTENTS     VARCHAR2 ( 4000 )                                       /* 170 内容         */
 , FG_NEW       VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 180 最新FG       */
 , SIZE_FILE    NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 190 ﾌｧｲﾙｻｲｽﾞ     */
 , DYFILESET    VARCHAR2 (   14 )                                       /* 200 ﾌｧｲﾙ登録日時 */
 , USRTOROKU    VARCHAR2 (   10 )                                       /* 210 ﾌｧｲﾙ登録者   */
 , SETGUIID     VARCHAR2 (   10 )                                       /* 220 登録画面ID   */
 , FGKOSHIN     VARCHAR2 (    1 )       DEFAULT '1'                     /* 230 変更許可FG   */
 , FGKOKAI      VARCHAR2 (    1 )       DEFAULT '1'                     /* 240 公開許可FG   */
 , SRCHKEY1     VARCHAR2 (  500 )                                       /* 250 検索ｷｰ1      */
 , SRCHKEY2     VARCHAR2 (  500 )                                       /* 270 検索ｷｰ2      */
 , SRCHKEY3     VARCHAR2 (  500 )                                       /* 280 検索ｷｰ3      */
 , SRCHKEY4     VARCHAR2 (  500 )                                       /* 290 検索ｷｰ4      */
 , SRCHKEY5     VARCHAR2 (  500 )                                       /* 300 検索ｷｰ5      */
 , SRCHKEY6     VARCHAR2 (  500 )                                       /* 310 検索ｷｰ6      */
 , SRCHKEY7     VARCHAR2 (  500 )                                       /* 320 検索ｷｰ7      */
 , SRCHKEY8     VARCHAR2 (  500 )                                       /* 330 検索ｷｰ8      */
 , SRCHKEY9     VARCHAR2 (  500 )                                       /* 340 検索ｷｰ9      */
 , SRCHKEY10    VARCHAR2 (  500 )                                       /* 350 検索ｷｰ10     */
 , UNIQ         NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (   14 )                                       /* 820 登録日時     */
 , PGSET        VARCHAR2 (   10 )                                       /* 830 作成PG       */
 , PGPSET       VARCHAR2 (   10 )                                       /* 840 作成親PG     */
 , USRSET       VARCHAR2 (   10 )                                       /* 850 作成者       */
 , DYUPD        VARCHAR2 (   14 )                                       /* 860 更新日時     */
 , PGUPD        VARCHAR2 (   10 )                                       /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (   10 )                                       /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (   10 )                                       /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );


CREATE SEQUENCE GE39S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;


CREATE OR REPLACE TRIGGER GE39T00 
  BEFORE INSERT ON GE39
  FOR EACH ROW 
  BEGIN 
    SELECT GE39S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
